==> calligra_2.9.9.orig.tar.xz: calligra-2.9.9/stage/plugins/pageeffects/matrixwipe/parallelsnakes/KPrParallelSnakesWipeEffectFactory.h <==
/* This file is part of the KDE project
   Copyright (C) 2008 Marijn Kruisselbrink <mkruisselbrink@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KPRPARALLELSNAKESWIPEEFFECTFACTORY_H
#define KPRPARALLELSNAKESWIPEEFFECTFACTORY_H

#include <KPrPageEffectFactory.h>

class KPrParallelSnakesWipeEffectFactory : public KPrPageEffectFactory
{
public:
    KPrParallelSnakesWipeEffectFactory();
    virtual ~KPrParallelSnakesWipeEffectFactory();
    virtual QString subTypeName(int subType) const;

    enum SubType {
        VerticalTopSameIn,
        VerticalTopSameOut,
        VerticalBottomSameIn,
        VerticalBottomSameOut,
        VerticalTopLeftOppositeIn,
        VerticalTopLeftOppositeOut,
        VerticalBottomLeftOppositeIn,
        VerticalBottomLeftOppositeOut,
        HorizontalLeftSameIn,
        HorizontalLeftSameOut,
        HorizontalRightSameIn,
        HorizontalRightSameOut,
        HorizontalTopLeftOppositeIn,
        HorizontalTopLeftOppositeOut,
        HorizontalTopRightOppositeIn,
        HorizontalTopRightOppositeOut,
        DiagonalBottomLeftOppositeIn,
        DiagonalBottomLeftOppositeOut,
        DiagonalTopLeftOppositeIn,
        DiagonalTopLeftOppositeOut
    };
};

#endif /* KPRPARALLELSNAKESWIPEEFFECTFACTORY_H */

==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/stage/plugins/pageeffects/matrixwipe/parallelsnakes/KPrParallelSnakesWipeEffectFactory.h <==
/* This file is part of the KDE project
   Copyright (C) 2008 Marijn Kruisselbrink <mkruisselbrink@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KPRPARALLELSNAKESWIPEEFFECTFACTORY_H
#define KPRPARALLELSNAKESWIPEEFFECTFACTORY_H

#include <KPrPageEffectFactory.h>

class KPrParallelSnakesWipeEffectFactory : public KPrPageEffectFactory
{
public:
    KPrParallelSnakesWipeEffectFactory();
    ~KPrParallelSnakesWipeEffectFactory() override;
    QString subTypeName(int subType) const override;

    enum SubType {
        VerticalTopSameIn,
        VerticalTopSameOut,
        VerticalBottomSameIn,
        VerticalBottomSameOut,
        VerticalTopLeftOppositeIn,
        VerticalTopLeftOppositeOut,
        VerticalBottomLeftOppositeIn,
        VerticalBottomLeftOppositeOut,
        HorizontalLeftSameIn,
        HorizontalLeftSameOut,
        HorizontalRightSameIn,
        HorizontalRightSameOut,
        HorizontalTopLeftOppositeIn,
        HorizontalTopLeftOppositeOut,
        HorizontalTopRightOppositeIn,
        HorizontalTopRightOppositeOut,
        DiagonalBottomLeftOppositeIn,
        DiagonalBottomLeftOppositeOut,
        DiagonalTopLeftOppositeIn,
        DiagonalTopLeftOppositeOut
    };
};

#endif /* KPRPARALLELSNAKESWIPEEFFECTFACTORY_H */
